@@ -21,11 +21,14 @@ def dissociate(corpus, output=sys.stdout):
     
 
 def main(args=sys.argv[1:]):
-    parser = OptionParser()
+    parser = OptionParser('%prog <path_or_url> <path_or_url> <...>')
     options, args = parser.parse_args()
 
     corpus = Corpus()
-    corpus.feed_stuff(*args)
+    if args:
+        corpus.feed_stuff(*args)
+    else:
+        corpus.feed_stream(sys.stdin.read())
     corpus.scramble()
     dissociate(corpus)
 
