@@ -9,11 +9,12 @@ from pprint import pprint
 from wordstream.api import Corpus
 
 def main(args=sys.argv[1:]):
-    parser = OptionParser()
+    parser = OptionParser('%prog [options] <path_or_url> <path_or_url> <...>')
     parser.add_option('--print-corpus', dest='print_corpus', default=False,
-                      action='store_true')
+                      action='store_true',
+                      help="print the given corpus of associations")
     parser.add_option('-n', type='int', dest='n', default=1,
-                      help='number of words to eat')
+                      help='number of words to eat per munch')
     options, args = parser.parse_args()
 
     corpus = Corpus()
@@ -21,6 +22,7 @@ def main(args=sys.argv[1:]):
     corpus.feed_stuff(*args)
     if options.print_corpus:
         pprint(corpus)
+        sys.exit(0)
 
     n = 1
 
